|bmlab|
=======

|PyPI Version| |Build Status| |Coverage Status| |Docs Status|


This is a Python library for the post-measurement analysis of
Brillouin microscopy data.


Documentation
-------------
The documentation, including the code reference and examples, is available at
`bmlab.readthedocs.io <https://bmlab.readthedocs.io/en/stable/>`__.


Installation
------------

::

    pip install bmlab

For more options, please check out the `documentation
<https://bmlab.readthedocs.io/en/latest/sec_getting_started.html#installation>`__.


Contributing
------------
Please read our `information for developers
<https://bmlab.readthedocs.io/en/latest/sec_develop.html>`__.


.. |bmlab| image:: https://raw.github.com/BrillouinMicroscopy/bmlab/main/docs/logo/bmlab.png
.. |PyPI Version| image:: https://img.shields.io/pypi/v/bmlab.svg
   :target: https://pypi.python.org/pypi/bmlab
.. |Build Status| image:: https://img.shields.io/github/workflow/status/BrillouinMicroscopy/bmlab/Checks
   :target: https://github.com/BrillouinMicroscopy/bmlab/actions?query=workflow%3AChecks
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/BrillouinMicroscopy/bmlab/main.svg
   :target: https://codecov.io/gh/BrillouinMicroscopy/bmlab
.. |Docs Status| image:: https://readthedocs.org/projects/bmlab/badge/?version=latest
   :target: https://readthedocs.org/projects/bmlab/builds/
